@@ -306,7 +306,7 @@ plotPolygons <- function(spe, colourBy="darkgrey", colourLog=FALSE,
     p <- p + theme_minimal() + theme(legend.position="right",
         plot.title.position="plot",plot.title=element_text(face="bold",size=14),
             plot.margin=margin(0, 0, 0, 0),
-            panel.background=element_rect(fill=bgColor, color=bgColor, size=1),
+            panel.background=element_rect(fill=bgColor, color=bgColor, linewidth=1),
             panel.border = element_rect(color="black", fill=NA, linewidth=0.1),
             panel.grid.minor=element_blank()
         ) + labs(title=sampleId, fill=colourBy)
@@ -349,7 +349,6 @@ plotPolygons <- function(spe, colourBy="darkgrey", colourLog=FALSE,
 #' adds a title to the combined plot.
 #'
 #' @importFrom ggpubr ggarrange annotate_figure
-#' @importFrom tmap tmap_grob
 #' @export
 #'
 #' @examples
@@ -596,7 +595,7 @@ qcFlagPlots <- function(spe, fov=unique(spe$fov),
     #     ggplot2::theme(panel.background=element_rect(fill="black"))
     # final
     legp <- .make_outlier_plot(spe$polygons, fov, "collapsed_color",
-                               outlier_palette, leg = TRUE) +
+                                outlier_palette, leg = TRUE) +
         plot_func() +
         ggplot2::theme(legend.title = ggplot2::element_blank()) +
         # scale "robuste" per evitare il drop delle classi assenti
@@ -628,7 +627,7 @@ qcFlagPlots <- function(spe, fov=unique(spe$fov),
 
     if (theme[1] == "dark") {
         final <- final +
-            ggplot2::theme(panel.background = ggplot2::element_rect(fill = "black"))
+            ggplot2::theme(panel.background = ggplot2::element_rect(fill="black"))
     }
     final
 
